{ config, lib, pkgs, ... }:
{
  imports = [
    ./config.nix
    #<stockholm/lass/2configs/hw/x220.nix>
    #<stockholm/lass/2configs/boot/universal.nix>
    <nixpkgs/nixos/modules/installer/scan/not-detected.nix>
    <stockholm/krebs/2configs/hw/x220.nix>
  ];

  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.efiSupport = true;
  boot.loader.grub.efiInstallAsRemovable = true;
  boot.loader.grub.device = "/dev/disk/by-id/wwn-0x5002538d702f5ac6";
  boot.initrd.luks.devices.ssd.device = "/dev/disk/by-id/wwn-0x5002538d702f5ac6-part3";

  boot.initrd.availableKernelModules = [ "ehci_pci" "ahci" "xhci_pci" "sd_mod" "sdhci_pci" ];
  boot.initrd.kernelModules = [ "dm-snapshot" ];
  boot.kernelModules = [ "kvm-intel" ];
  boot.extraModulePackages = [ ];

  fileSystems."/" = {
    device = "/dev/disk/by-uuid/298eb635-8db2-4c15-a73d-2e0d6afa10e8";
    fsType = "xfs";
  };

  fileSystems."/home" = {
    device = "/dev/disk/by-uuid/eec94bef-e745-4d95-ad17-4df728f5fd31";
    fsType = "xfs";
  };

  fileSystems."/boot" = {
    device = "/dev/disk/by-uuid/D975-2CAB";
    fsType = "vfat";
  };

  swapDevices = [ ];

  nix.maxJobs = lib.mkDefault 4;
  powerManagement.cpuFreqGovernor = lib.mkDefault "powersave";

  services.udev.extraRules = ''
    SUBSYSTEM=="net", ATTR{address}=="00:24:d7:f0:a0:0c", NAME="wl0"
    SUBSYSTEM=="net", ATTR{address}=="f0:de:f1:71:cb:35", NAME="et0"
  '';

  services.thinkfan.enable = true;
  services.thinkfan.levels = ''
    (0,     0,      55)
    (1,     48,     60)
    (2,     50,     61)
    (3,     52,     63)
    (6,     60,     65)
    (7,     80,     85)
    (127,   90,     32767)
  '';

  services.logind.lidSwitch = "ignore";
  services.logind.lidSwitchDocked = "ignore";

}
